@@ -1,7 +1,8 @@
 # -*- coding:utf-8 -*-
 from trdb2py.config import loadConfig
 from trdb2py.trdb2 import simTradings, getAssetCandles, simTrading
-from trdb2py.utils import str2Asset, nextWeekDay, asset2Str
+from trdb2py.utils import str2asset, nextWeekDay, asset2str
+from trdb2py.timeutils import str2timestamp
 from trdb2py.pdutils import buildPNLReport
 from trdb2py.statistics import calcPNLWinRateInYear, buildPNLWinRateInYears, buildPNLWinRateInMonths, buildPNLListWinRateInYears2, buildPNLListWinRateInMonths2
 from trdb2py.plotly import showAssetCandles, showHeatmap, showHeatmapWinRateInYears, showWinRateInYears, showHeatmapWinRateInMonths, showWinRateInMonths
